Modules
- error
- global_
event_ log - message
- A message is a data structure that represents either an instruction to be passed to a process (command), or a record of something that has happened (event) - typically in response to the processing of a command.
- outbox
- projection
- stream